==> alghwalbi_easy_router-1.0.0.tar.gz: lib/src/easy_route.dart <==
part of alghwalbi_easy_router;

class PageRoute {
  final String path;
  final BeamPage Function(BuildContext, BeamState, Object?) builder;
  PageRoute(this.path, this.builder);
}

class EasyRouter {
  static List<String> stackRouteHistory = [];

  /// pageTitle is null in web
  static Future Function(String route, String? pageTitle)? onNavigate;
  // your not found page default is BeamPage.notFound
  static BeamPage? notFoundPageEx;
  static String? notFoundRedirectNamed;
  static BeamLocation<RouteInformationSerializable<dynamic>>? notFoundRedirect;

  /// default is BeamPageType.cupertino
  static BeamPageType? iosBeamPageType;

  /// default is BeamPageType.noTransition
  static BeamPageType? webBeamPageType;

  /// default is BeamPageType.material
  static BeamPageType? androidBeamPageType;
  static Map<String, dynamic Function(BuildContext, BeamState, Object?)>?
      _routes;

  static Map<String, dynamic Function(BuildContext, BeamState, Object?)>?
      allAppRoutes;

  /// try to give value to routes first
  static Map<String, dynamic Function(BuildContext, BeamState, Object?)>
      get routes {
    if (_routes == null && allAppRoutes != null) {
      Map<String, dynamic Function(BuildContext, BeamState, Object?)> r = {};

      for (var p in pages) {
        var rr = p();
        if (rr == null) continue;
        r[rr.path] = rr.builder;
      }
      _routes = r;
      if (allAppRoutes != null) _routes!.addAll(allAppRoutes!);

      if (_routes!.isEmpty) _routes = null;
    }
    return _routes ?? {};
  }

  static List<PageRoute? Function()> pages = [];

  static BeamerParser get getBeamerParser => BeamerParser();

  static BeamerBackButtonDispatcher get getBeamerBackButtonDispatcher =>
      BeamerBackButtonDispatcher(
        delegate: routerDelegate,
        alwaysBeamBack: true,
      );

  static void setPathUrlStrategyEx() {
    Beamer.setPathUrlStrategy();
  }

  static BeamPage beamPageEx(
      {required Widget child,
      String? title,
      LocalKey? key,
      String? popToNamedEx,
      bool Function(BuildContext, BeamerDelegate,
              RouteInformationSerializable<dynamic>, BeamPage)?
          onPopPageEx}) {
    return onPopPageEx != null
        ? BeamPage(
            child: child,
            title: title,
            key: key,
            type: _getPageTransation(),
            popToNamed: popToNamedEx,
            onPopPage: onPopPageEx)
        : BeamPage(
            child: child,
            title: title,
            key: key,
            type: _getPageTransation(),
            popToNamed: popToNamedEx,
          );
  }

  static void back(BuildContext context, {String? popFailedRoute}) {
    if (!kIsWeb) {
      if (Navigator.canPop(context)) {
        if (stackRouteHistory.isEmpty) {
          stackRouteHistory.removeLast();
        }
        Navigator.pop(context);
      } else {
        go(
            context: context,
            route: popFailedRoute ?? '/',
            animationType: AnimationTypes.opacity);
      }
      return;
    }
    if (Beamer.of(context).canBeamBack) {
      Beamer.of(context).beamBack();
    } else {
      if (popFailedRoute != null) {
        go(context: context, route: popFailedRoute, replaceRoute: true);
      } else {
        Navigator.pop(context);
      }
    }
  }

  static void go(
      {required BuildContext context,
      required String route,
      Map<String, dynamic>? data,
      bool replaceRoute = false,
      AnimationTypes animationType = AnimationTypes.none,
      Function(BuildContext)? invalidRouterDialog}) {
    if (!kIsWeb) {
      if (!route.startsWith('/') && stackRouteHistory.isEmpty) {
        route = '${stackRouteHistory.last}/$route';
      }
      stackRouteHistory.add(route);
      var state = BeamState.fromUri(Uri.parse(route));
      var k2 = route.split('/');
      for (var key in EasyRouter.routes.keys) {
        var k1 = key.split('/');
        if (k1.length != k2.length) continue;
        var match = true;
        for (var i = 0; i < k1.length; i++) {
          if (!k1[i].contains(':') && k1[i] != k2[i]) {
            match = false;
            continue;
          }
        }
        if (!match) continue;

        for (var i = 0; i < k1.length; i++) {
          if (k1[i].contains(':')) {
            var s = Map<String, String>.from(state.pathParameters);
            s[k1[i].substring(1)] = k2[i];
            state = state.copyWith(pathParameters: s);
          }
        }

        BeamPage? widget = EasyRouter.routes[key]?.call(context, state, data);
        if (widget != null) {
          onNavigate?.call(route, widget.title);
          NavigatorHelper.navigateTo(context, () => widget.child,
              replaceAll: replaceRoute, animationType: animationType);
          return;
        }
      }
      invalidRouterDialog ??
          NavigatorHelper.defaultShowInvalidRouterDialog(context);
      return;
    }

    onNavigate?.call(route, null);
    if (replaceRoute) {
      Beamer.of(context)
          .beamToReplacementNamed(route, data: data, stacked: false);
    } else {
      Beamer.of(context).beamToNamed(route, data: data);
    }
  }

  static BeamPageType _getPageTransation() {
    if (kIsWeb) {
      return webBeamPageType ?? BeamPageType.noTransition;
    } else if (Platform.isIOS) {
      return iosBeamPageType ?? BeamPageType.cupertino;
    } else {
      return androidBeamPageType ?? BeamPageType.material;
    }
  }

  static var routerDelegate = BeamerDelegate(
    setBrowserTabTitle: false,
    notFoundRedirectNamed: notFoundRedirectNamed,
    notFoundRedirect: notFoundRedirect,
    notFoundPage: notFoundPageEx ?? BeamPage.notFound,
    navigatorObservers: [HeroController(), defaultLifecycleObserver],
    locationBuilder: RoutesLocationBuilder(routes: routes),
  );
}

==> alghwalbi_easy_router-1.0.3.tar.gz: lib/src/easy_route.dart <==
part of alghwalbi_easy_router;

class PageRoute {
  final String path;
  final BeamPage Function(BuildContext, BeamState, Object?) builder;
  PageRoute(this.path, this.builder);
}

class EasyRouter {
  static List<String> stackRouteHistory = [];

  /// pageTitle is null in web
  static Future Function(String route, String? pageTitle)? onNavigate;
  // your not found page default is BeamPage.notFound
  static BeamPage? notFoundPageEx;
  static String? notFoundRedirectNamed;
  static BeamLocation<RouteInformationSerializable<dynamic>>? notFoundRedirect;

  /// default is BeamPageType.cupertino
  static BeamPageType? iosEasyRouterPageType;

  /// default is BeamPageType.noTransition
  static BeamPageType? webEasyRouterPageType;

  /// default is BeamPageType.material
  static BeamPageType? androidEasyRouterPageType;
  static Map<String, dynamic Function(BuildContext, BeamState, Object?)>?
      _routes;

  static Map<String, dynamic Function(BuildContext, BeamState, Object?)>?
      allAppRoutes;

  /// try to give value to routes first
  static Map<String, dynamic Function(BuildContext, BeamState, Object?)>
      get routes {
    if (_routes == null && allAppRoutes != null) {
      Map<String, dynamic Function(BuildContext, BeamState, Object?)> r = {};

      for (var p in pages) {
        var rr = p();
        if (rr == null) continue;
        r[rr.path] = rr.builder;
      }
      _routes = r;
      if (allAppRoutes != null) _routes!.addAll(allAppRoutes!);

      if (_routes!.isEmpty) _routes = null;
    }
    return _routes ?? {};
  }

  static List<PageRoute? Function()> pages = [];

  static BeamerParser get getEasyRouterParser => BeamerParser();

  static BeamerBackButtonDispatcher get getEasyRouterBackButtonDispatcher =>
      BeamerBackButtonDispatcher(
        delegate: easyRouterDelegate,
        alwaysBeamBack: true,
      );

  static void setPathUrlStrategyEx() {
    Beamer.setPathUrlStrategy();
  }

  static BeamPage routeInfo(
      {required Widget child,
      String? title,
      LocalKey? key,
      String? popToNamedEx,
      bool Function(BuildContext, BeamerDelegate,
              RouteInformationSerializable<dynamic>, BeamPage)?
          onPopPageEx}) {
    return onPopPageEx != null
        ? BeamPage(
            child: child,
            title: title,
            key: key,
            type: _getPageTransation(),
            popToNamed: popToNamedEx,
            onPopPage: onPopPageEx)
        : BeamPage(
            child: child,
            title: title,
            key: key,
            type: _getPageTransation(),
            popToNamed: popToNamedEx,
          );
  }

  static void back(BuildContext context, {String? popFailedRoute}) {
    if (!kIsWeb) {
      if (Navigator.canPop(context)) {
        if (stackRouteHistory.isEmpty) {
          stackRouteHistory.removeLast();
        }
        Navigator.pop(context);
      } else {
        go(
            context: context,
            route: popFailedRoute ?? '/',
            animationType: AnimationTypes.opacity);
      }
      return;
    }
    if (Beamer.of(context).canBeamBack) {
      Beamer.of(context).beamBack();
    } else {
      if (popFailedRoute != null) {
        go(context: context, route: popFailedRoute, replaceRoute: true);
      } else {
        Navigator.pop(context);
      }
    }
  }

  static void go(
      {required BuildContext context,
      required String route,
      Map<String, dynamic>? data,
      bool replaceRoute = false,
      AnimationTypes animationType = AnimationTypes.none,
      Function(BuildContext)? invalidRouterDialog}) {
    if (!kIsWeb) {
      if (!route.startsWith('/') && stackRouteHistory.isEmpty) {
        route = '${stackRouteHistory.last}/$route';
      }
      stackRouteHistory.add(route);
      var state = BeamState.fromUri(Uri.parse(route));
      var k2 = route.split('/');
      for (var key in EasyRouter.routes.keys) {
        var k1 = key.split('/');
        if (k1.length != k2.length) continue;
        var match = true;
        for (var i = 0; i < k1.length; i++) {
          if (!k1[i].contains(':') && k1[i] != k2[i]) {
            match = false;
            continue;
          }
        }
        if (!match) continue;

        for (var i = 0; i < k1.length; i++) {
          if (k1[i].contains(':')) {
            var s = Map<String, String>.from(state.pathParameters);
            s[k1[i].substring(1)] = k2[i];
            state = state.copyWith(pathParameters: s);
          }
        }

        BeamPage? widget = EasyRouter.routes[key]?.call(context, state, data);
        if (widget != null) {
          onNavigate?.call(route, widget.title);
          NavigatorHelper.navigateTo(context, () => widget.child,
              replaceAll: replaceRoute, animationType: animationType);
          return;
        }
      }
      invalidRouterDialog ??
          NavigatorHelper.defaultShowInvalidRouterDialog(context);
      return;
    }

    onNavigate?.call(route, null);
    if (replaceRoute) {
      Beamer.of(context)
          .beamToReplacementNamed(route, data: data, stacked: false);
    } else {
      Beamer.of(context).beamToNamed(route, data: data);
    }
  }

  static BeamPageType _getPageTransation() {
    if (kIsWeb) {
      return webEasyRouterPageType ?? BeamPageType.noTransition;
    } else if (Platform.isIOS) {
      return iosEasyRouterPageType ?? BeamPageType.cupertino;
    } else {
      return androidEasyRouterPageType ?? BeamPageType.material;
    }
  }

  static var easyRouterDelegate = BeamerDelegate(
    setBrowserTabTitle: false,
    notFoundRedirectNamed: notFoundRedirectNamed,
    notFoundRedirect: notFoundRedirect,
    notFoundPage: notFoundPageEx ?? BeamPage.notFound,
    navigatorObservers: [HeroController(), defaultLifecycleObserver],
    locationBuilder: RoutesLocationBuilder(routes: routes),
  );
}
